<?php
/**
 * Core functions.
 *
 * @package SuperBiz
 */

if ( ! function_exists( 'superbiz_get_option' ) ) :

	/**
	 * Get theme option.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Option key.
	 * @return mixed Option value.
	 */
	function superbiz_get_option( $key = '' ) {

		$default_options = superbiz_get_default_theme_options();

		if ( empty( $key ) ) {
			return;
		}

		$theme_options = (array) get_theme_mod( 'theme_options' );
		$theme_options = wp_parse_args( $theme_options, $default_options );

		$value = null;

		if ( isset( $theme_options[ $key ] ) ) {
			$value = $theme_options[ $key ];
		}

		return $value;

	}

endif;

if ( ! function_exists( 'superbiz_get_options' ) ) :

	/**
	 * Get all theme options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Theme options.
	 */
	function superbiz_get_options() {

		$value = array();
		$value = get_theme_mod( 'theme_options' );
		return $value;

	}

endif;

if ( ! function_exists( 'superbiz_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function superbiz_get_global_layout_options() {

		$choices = array(
			'left-sidebar'  => esc_html__( 'Primary Sidebar - Content', 'superbiz' ),
			'right-sidebar' => esc_html__( 'Content - Primary Sidebar', 'superbiz' ),
			'no-sidebar'    => esc_html__( 'No Sidebar', 'superbiz' ),
		);
		$output = apply_filters( 'superbiz_filter_layout_options', $choices );
		return $output;

	}

endif;

if ( ! function_exists( 'superbiz_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function superbiz_get_archive_layout_options() {

		$choices = array(
			'full'    => esc_html__( 'Full Post', 'superbiz' ),
			'excerpt' => esc_html__( 'Post Excerpt', 'superbiz' ),
		);
		$output = apply_filters( 'superbiz_filter_archive_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'superbiz_implement_excerpt_length' ) ) :

	/**
	 * Implement excerpt length
	 *
	 * @since 1.0.0
	 *
	 * @param int $length The number of words.
	 * @return int Excerpt length.
	 */
	function superbiz_implement_excerpt_length( $length ) {

		$excerpt_length = superbiz_get_option( 'excerpt_length' );
		if ( is_admin() ) {
                return $length;
        }
		if ( empty( $excerpt_length ) ) {
			$excerpt_length = $length;
		}
		return apply_filters( 'superbiz_filter_excerpt_length', absint( $excerpt_length ) );

	}

endif;



if ( ! function_exists( 'superbiz_content_more_link' ) ) :

	/**
	 * Implement read more in content.
	 *
	 * @since 1.0.0
	 *
	 * @param string $more_link Read More link element.
	 * @param string $more_link_text Read More text.
	 * @return string Link.
	 */
	function superbiz_content_more_link( $more_link, $more_link_text ) {

		$flag_apply_excerpt_read_more = apply_filters( 'superbiz_filter_excerpt_read_more', true );

		if ( true !== $flag_apply_excerpt_read_more ) {
			return $more_link;
		}

		$read_more_text = superbiz_get_option( 'read_more_text' );
		if ( ! empty( $read_more_text ) ) {
			$more_link = str_replace( $more_link_text, esc_html( $read_more_text ), $more_link );
		}
		return $more_link;

	}

endif;

if ( ! function_exists( 'superbiz_implement_read_more' ) ) :

	/**
	 * Implement read more in excerpt
	 *
	 * @since 1.0.0
	 *
	 * @param string $more The string shown within the more link.
	 * @return string The excerpt.
	 */
	function superbiz_implement_read_more( $more ) {

		$flag_apply_excerpt_read_more = apply_filters( 'superbiz_filter_excerpt_read_more', true );
		if ( true !== $flag_apply_excerpt_read_more ) {
			return $more;
		}

		$output = $more;
		$read_more_text = superbiz_get_option( 'read_more_text' );
		if ( is_admin() ) {
                return $more;
        }
		if ( ! empty( $read_more_text ) ) {
			$output = ' <a href="'. esc_url( get_permalink() ) . '" class="more-link">' . esc_html( $read_more_text ) . '</a>';
			$output = apply_filters( 'superbiz_filter_read_more_link' , $output );
		}
		return $output;

	}

endif;



if ( ! function_exists( 'superbiz_hook_read_more_filters' ) ) :

	/**
	 * Hook read more filters.
	 *
	 * @since 1.0.0
	 */
	function superbiz_hook_read_more_filters() {
			add_filter( 'excerpt_length', 'superbiz_implement_excerpt_length', 999 );
			add_filter( 'the_content_more_link', 'superbiz_content_more_link', 10, 2 );
			add_filter( 'excerpt_more', 'superbiz_implement_read_more' );
	}
endif;

add_action( 'wp', 'superbiz_hook_read_more_filters' );


if ( ! function_exists( 'superbiz_custom_posts_navigation' ) ) :

	/**
	 * Posts navigation.
	 *
	 * @since 1.0.0
	 */
	function superbiz_custom_posts_navigation() {

		the_posts_pagination();

	}
endif;

add_action( 'superbiz_action_posts_navigation', 'superbiz_custom_posts_navigation' );